class SignaldException(Exception):
    """
    Base class to translate signald's response payloads into python exceptions
    """

    def __init__(self, error_type, error_msg):
        self.type = error_type
        self.msg = error_msg

    def __str__(self):
        return f"{self.type}: {self.msg}"


def raise_error(response: dict):
    """
    Raise a python exception using a signald response payload
    """
    if response.get("type") == "profile_not_available":
        raise SignaldException("profile_not_available", response.get("data"))

    data = response.get("data", dict())
    if isinstance(data, list):
        error = response.get("error", False)
    else:
        error = response.get("error", data.get("error", False))
    if error:
        if isinstance(error, bool):
            type_ = response.get("type")
            msg = response["data"].get("message", "")
            req = response["data"].get("request", "")
            msg += f"{req}"
        elif isinstance(error, dict):
            type_ = error.get("type")
            msg = error.get("message", "")
            msg += "".join(error.get("validationResults", [""]))
        raise SignaldException(type_, msg)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pysignald_async']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'pysignald-async',
    'version': '0.1.6',
    'description': 'Python bindings for signald',
    'long_description': '# Signald python bindings\n\nMost of the content here is generated by `util/generate_api.py` that uses\nthe output of the \'protocol\' request of the [signald](https://gitlab.com/signald/signald) [API](https://docs.signald.org/).\n\nSince this output is incomplete, a few manual additions are present in `pysignald_async/api.py`.\n\n## Install\n\n`pip install pysignald-async`\n\n## Usage\n\nAn example can be found in [this signal/XMPP gateway](https://gitlab.com/nicocool84/spectrum2_signald/-/blob/master/spectrum2_signald/signald.py).\n\n\n```py\nimport asyncio\n\nfrom pysignald_async import SignaldAPI\n\nasync def main():\n    loop = asyncio.get_running_loop()\n    _, signald = await loop.create_unix_connection(\n        SignaldAPI, path=SIGNALD_SOCKET_PATH)\n    await signald.register(username="+XXXXXX")\n    # Some async code to get the SMS code\n    await signald.verify(username="+XXXXXX", code=code)\n    await signald.on_con_lost\n\nSIGNALD_SOCKET_PATH = "/var/run/signald/signald.sock"\n\nasyncio.run(main())\n\n```\n\n`TODO: Write a better README`\n',
    'author': 'Nicolas Cedilnik',
    'author_email': 'nicoco@nicoco.fr',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/nicocool84/pysignald-async',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
